/* _dict.cc 12/12/1999 22.07.42 */
/* modemconf.cc 07/09/2000 23.20.16 */
PUBLIC MODULE_modemconf::MODULE_modemconf (void);
PUBLIC void MODULE_modemconf::setmenu (DIALOG&dia,
	 MENU_CONTEXT context);
PUBLIC int MODULE_modemconf::domenu (MENU_CONTEXT context,
	 const char *key);
PUBLIC int MODULE_modemconf::dohtml (const char *key);
PUBLIC void MODULE_modemconf::usage (SSTRINGS&tb);
PUBLIC int MODULE_modemconf::execmain (int argc, char *argv[], bool);
/* modemconfedit.cc 07/09/2000 23.18.54 */
MODEM::MODEM (void);
int MODEM::get_device (void);
void MODEM::set_device (int new_dev);
int MODEM::detect_device (void);
